@@ -35,12 +35,18 @@ INTERNALERROR_ECDNDBERROR = 'InternalError.EcdnDbError'
 # 系统错误，请联系腾讯云工程师进一步排查。
 INTERNALERROR_ECDNSYSTEMERROR = 'InternalError.EcdnSystemError'
 
+# 后端服务错误,请稍后重试 。
+INTERNALERROR_PROXYSERVER = 'InternalError.ProxyServer'
+
 # 标签键不存在。
 INVALIDPARAMETER_ECDNCAMTAGKEYNOTEXIST = 'InvalidParameter.EcdnCamTagKeyNotExist'
 
 # 无法解析证书信息。
 INVALIDPARAMETER_ECDNCERTNOCERTINFO = 'InvalidParameter.EcdnCertNoCertInfo'
 
+# 缓存配置不合法 。
+INVALIDPARAMETER_ECDNCONFIGINVALIDCACHE = 'InvalidParameter.EcdnConfigInvalidCache'
+
 # 域名状态不合法。
 INVALIDPARAMETER_ECDNDOMAININVALIDSTATUS = 'InvalidParameter.EcdnDomainInvalidStatus'
 
@@ -125,6 +131,15 @@ RESOURCENOTFOUND_ECDNPROJECTNOTEXISTS = 'ResourceNotFound.EcdnProjectNotExists'
 # 未开通ECDN服务，请开通后使用此接口。
 RESOURCENOTFOUND_ECDNUSERNOTEXISTS = 'ResourceNotFound.EcdnUserNotExists'
 
+# 域名已锁定,请联系腾讯云工程师 。
+RESOURCEUNAVAILABLE_ECDNDOMAINISLOCKED = 'ResourceUnavailable.EcdnDomainIsLocked'
+
+# 域名未下线，请检查后重试。
+RESOURCEUNAVAILABLE_ECDNDOMAINISNOTOFFLINE = 'ResourceUnavailable.EcdnDomainIsNotOffline'
+
+# 域名已下线，请检查后重试。
+RESOURCEUNAVAILABLE_ECDNDOMAINISNOTONLINE = 'ResourceUnavailable.EcdnDomainIsNotOnline'
+
 # 子账号禁止查询整体数据。
 UNAUTHORIZEDOPERATION_CDNACCOUNTUNAUTHORIZED = 'UnauthorizedOperation.CdnAccountUnauthorized'
 
@@ -167,6 +182,9 @@ UNAUTHORIZEDOPERATION_ECDNHOSTISOWNEDBYOTHER = 'UnauthorizedOperation.EcdnHostIs
 # ECDN子账号加速域名未授权。
 UNAUTHORIZEDOPERATION_ECDNHOSTUNAUTHORIZED = 'UnauthorizedOperation.EcdnHostUnauthorized'
 
+# 请前往CDN控制台进行操作 。
+UNAUTHORIZEDOPERATION_ECDNMIGRATEDCDN = 'UnauthorizedOperation.EcdnMigratedCdn'
+
 # 子账号没有授权域名权限，请授权后重试。
 UNAUTHORIZEDOPERATION_ECDNNODOMAINUNAUTHORIZED = 'UnauthorizedOperation.EcdnNoDomainUnauthorized'
 
@@ -187,3 +205,6 @@ UNAUTHORIZEDOPERATION_PROJECTNOPERMISSION = 'UnauthorizedOperation.ProjectNoPerm
 
 # ECDN 子账号项目未授权。
 UNAUTHORIZEDOPERATION_PROJECTSNOPERMISSION = 'UnauthorizedOperation.ProjectsNoPermission'
+
+# 未知错误,请稍后重试 。
+UNAUTHORIZEDOPERATION_UNKNOWN = 'UnauthorizedOperation.Unknown'
